;;
;; export-web-static.scm
;;
;; Generate private member info page.
;;
;; ISC License
;;
;; Copyright 2023 Brmlab, z.s.
;; Dominik Pantůček <dominik.pantucek@trustica.cz>
;;
;; Permission to use, copy, modify, and/or distribute this software
;; for any purpose with or without fee is hereby granted, provided
;; that the above copyright notice and this permission notice appear
;; in all copies.
;; 
;; THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
;; WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
;; WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE
;; AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
;; CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
;; OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
;; NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
;; CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
;;

(declare (unit export-web-static))

(module
 export-web-static
 (
  gen-html-members
  )

 (import scheme
	 (chicken base)
	 (chicken format)
	 (chicken pathname)
	 (chicken string)
	 brmember
	 util-dir
	 mbase
	 members-payments
	 cal-day
	 util-git
	 configuration)

 ;; Prints the HTML summary for given member to current-output-port
 (define (print-html-member mr)
   (print "<html>")
   (print "<head>")
   (print "<title>Brmlab member "
	  (brmember-nick mr)
	  "</title>")
   (print "</head>")
   (print "<body>")
   (print "<h1>Brmlab member " (brmember-nick mr) "</h1>")
   (print "<hr>")
   (print "<dl>")
   (print "<dt>Nick:</dt><dd>" (brmember-nick mr) "</dd>")
   (print "<dt>Id:</dt><dd>" (brmember-id mr) "</dd>")
   (print "</dl>")
   (print "<hr>")
   (print "<h2>Member file</h2>")
   (print "<pre>")
   (print (string-translate*
	   (string-intersperse (brmember-source mr) "\n")
	   '(("&" . "&amp;") ("<" . "&lt;") (">" . "&gt;") ("\"" . "&quot;"))))
   (print "</pre>")
   (print "<hr>")
   (print "<h2>Payments history</h2>")
   (print "<table>")
   (print "<thead><tr><th>Date</th><th>Type</th><th>Comment</th><th>Amount</th><th>Currency</th><th>Amount [CZK]</th><th>Balance</th></tr></thead>")
   (print "<tbody>")
   (for-each (lambda (hr)
	       (print "<tr><td>"
		      (cal-day->string (cadr hr))
		      "</td><td>"
		      (list-ref hr 6)
		      "</td><td>"
		      (list-ref hr 4)
		      "</td><td>"
		      (exact->inexact (list-ref hr 2))
		      "</td><td>"
		      (list-ref hr 3)
		      "</td><td>"
		      (list-ref hr 5)
		      "</td><td>"
		      (exact->inexact (car hr))
		      "</td></tr>"
	       ))
	     (brmember-balance-history mr))
   (print "</tbody>")
   (print "</table>")
   (print "<hr>")
   (print "<h2>Member File Git Log</h2>")
   (print "<pre>")
   (for-each print
	     ((git (*members-directory*) #:output)
	      'log '-p '-- 
	      (brmember-file-name mr)))
   (print "</pre>")
   (print "</body>")
   (print "</html>"))

 ;; Generates a single member in given directory
 (define (gen-html-member mr dir)
   (let ((fname (format "~A.html" (brmember-id mr))))
     (with-output-to-file (make-pathname dir (format "~A.html" (brmember-nick mr)))
       (lambda ()
	 (print-html-member mr)))))

 ;; Generates all members in given directory
 (define (gen-html-members mb dir)
   (ensure-directory dir)
   (with-mbase-progress%
    mb dir mr
    (gen-html-member mr dir)))

 )
